@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Mikael Hallendal <micke@imendio.com>
  *          Martyn Russell <martyn@imendio.com>
@@ -488,7 +488,7 @@ contact_list_view_drag_data_get (GtkWidget        *widget,
 	switch (info) {
 	case DND_DRAG_TYPE_CONTACT_ID:
 		gtk_selection_data_set (selection, drag_atoms_source[info], 8,
-					(guchar*)str, strlen (str) + 1);
+					(guchar *) str, strlen (str) + 1);
 		break;
 	}
 
@@ -615,9 +615,10 @@ contact_list_view_row_activated (GtkTreeView       *view,
 }
 
 static void
-contact_list_view_voip_activated_cb (EmpathyCellRendererActivatable *cell,
-				     const gchar                    *path_string,
-				     EmpathyContactListView         *view)
+contact_list_start_voip_call (EmpathyCellRendererActivatable *cell,
+    const gchar                    *path_string,
+    EmpathyContactListView         *view,
+    gboolean with_video)
 {
 	EmpathyContactListViewPriv *priv = GET_PRIV (view);
 	GtkTreeModel               *model;
@@ -639,14 +640,31 @@ contact_list_view_voip_activated_cb (EmpathyCellRendererActivatable *cell,
 
 	if (contact) {
 		EmpathyCallFactory *factory;
-
 		factory = empathy_call_factory_get ();
-		empathy_call_factory_new_call (factory, contact);
-
+		empathy_call_factory_new_call_with_streams (factory, contact,
+			TRUE, with_video);
 		g_object_unref (contact);
 	}
 }
 
+static void
+contact_list_view_video_call_activated_cb (
+    EmpathyCellRendererActivatable *cell,
+    const gchar                    *path_string,
+    EmpathyContactListView         *view)
+{
+  contact_list_start_voip_call (cell, path_string, view, TRUE);
+}
+
+
+static void
+contact_list_view_audio_call_activated_cb (EmpathyCellRendererActivatable *cell,
+				     const gchar                    *path_string,
+				     EmpathyContactListView         *view)
+{
+  contact_list_start_voip_call (cell, path_string, view, FALSE);
+}
+
 static void
 contact_list_view_cell_set_background (EmpathyContactListView *view,
 				       GtkCellRenderer       *cell,
@@ -708,7 +726,8 @@ contact_list_view_pixbuf_cell_data_func (GtkTreeViewColumn     *tree_column,
 }
 
 static void
-contact_list_view_voip_cell_data_func (GtkTreeViewColumn      *tree_column,
+contact_list_view_audio_call_cell_data_func (
+				       GtkTreeViewColumn      *tree_column,
 				       GtkCellRenderer        *cell,
 				       GtkTreeModel           *model,
 				       GtkTreeIter            *iter,
@@ -721,7 +740,7 @@ contact_list_view_voip_cell_data_func (GtkTreeViewColumn      *tree_column,
 	gtk_tree_model_get (model, iter,
 			    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, &is_group,
 			    EMPATHY_CONTACT_LIST_STORE_COL_IS_ACTIVE, &is_active,
-			    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VOIP, &can_voip,
+			    EMPATHY_CONTACT_LIST_STORE_COL_CAN_AUDIO_CALL, &can_voip,
 			    -1);
 
 	g_object_set (cell,
@@ -732,6 +751,33 @@ contact_list_view_voip_cell_data_func (GtkTreeViewColumn      *tree_column,
 	contact_list_view_cell_set_background (view, cell, is_group, is_active);
 }
 
+static void
+contact_list_view_video_call_cell_data_func (
+				       GtkTreeViewColumn      *tree_column,
+				       GtkCellRenderer        *cell,
+				       GtkTreeModel           *model,
+				       GtkTreeIter            *iter,
+				       EmpathyContactListView *view)
+{
+	gboolean is_group;
+	gboolean is_active;
+	gboolean can_voip;
+
+	gtk_tree_model_get (model, iter,
+			    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, &is_group,
+			    EMPATHY_CONTACT_LIST_STORE_COL_IS_ACTIVE, &is_active,
+			    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VIDEO_CALL, &can_voip,
+			    -1);
+
+	g_object_set (cell,
+		      "visible", !is_group && can_voip,
+		      "icon-name", EMPATHY_IMAGE_VIDEO_CALL,
+		      NULL);
+
+	contact_list_view_cell_set_background (view, cell, is_group, is_active);
+}
+
+
 static void
 contact_list_view_avatar_cell_data_func (GtkTreeViewColumn     *tree_column,
 					 GtkCellRenderer       *cell,
@@ -948,12 +994,12 @@ contact_list_view_setup (EmpathyContactListView *view)
 	gtk_tree_view_column_add_attribute (col, cell,
 					    "is_group", EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP);
 
-	/* Voip Capability Icon */
+	/* Audio Call Icon */
 	cell = empathy_cell_renderer_activatable_new ();
 	gtk_tree_view_column_pack_start (col, cell, FALSE);
 	gtk_tree_view_column_set_cell_data_func (
 		col, cell,
-		(GtkTreeCellDataFunc) contact_list_view_voip_cell_data_func,
+		(GtkTreeCellDataFunc) contact_list_view_audio_call_cell_data_func,
 		view, NULL);
 
 	g_object_set (cell,
@@ -961,7 +1007,23 @@ contact_list_view_setup (EmpathyContactListView *view)
 		      NULL);
 
 	g_signal_connect (cell, "path-activated",
-			  G_CALLBACK (contact_list_view_voip_activated_cb),
+			  G_CALLBACK (contact_list_view_audio_call_activated_cb),
+			  view);
+
+	/* Video Call Icon */
+	cell = empathy_cell_renderer_activatable_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_cell_data_func (
+		col, cell,
+		(GtkTreeCellDataFunc) contact_list_view_video_call_cell_data_func,
+		view, NULL);
+
+	g_object_set (cell,
+		      "visible", FALSE,
+		      NULL);
+
+	g_signal_connect (cell, "path-activated",
+			  G_CALLBACK (contact_list_view_video_call_activated_cb),
 			  view);
 
 	/* Avatar */
@@ -1181,7 +1243,7 @@ empathy_contact_list_view_init (EmpathyContactListView *view)
 	/* Get saved group states. */
 	empathy_contact_groups_get_all ();
 
-	gtk_tree_view_set_row_separator_func (GTK_TREE_VIEW (view), 
+	gtk_tree_view_set_row_separator_func (GTK_TREE_VIEW (view),
 					      empathy_contact_list_store_row_separator_func,
 					      NULL, NULL);
 
@@ -1275,8 +1337,8 @@ empathy_contact_list_view_get_selected_group (EmpathyContactListView *view)
 }
 
 static gboolean
-contact_list_view_remove_dialog_show (GtkWindow   *parent, 
-				      const gchar *message, 
+contact_list_view_remove_dialog_show (GtkWindow   *parent,
+				      const gchar *message,
 				      const gchar *secondary_text)
 {
 	GtkWidget *dialog;
@@ -1291,9 +1353,9 @@ contact_list_view_remove_dialog_show (GtkWindow   *parent,
 				NULL);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  "%s", secondary_text);
-	 
+
 	gtk_widget_show (dialog);
-	 
+
 	res = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
@@ -1387,7 +1449,7 @@ contact_list_view_remove_activate_cb (GtkMenuItem            *menuitem,
 	contact = empathy_contact_list_view_dup_selected (view);
 
 	if (contact) {
-		gchar     *text; 
+		gchar     *text;
 		GtkWindow *parent;
 
 		parent = empathy_get_toplevel_window (GTK_WIDGET (view));
@@ -1397,7 +1459,7 @@ contact_list_view_remove_activate_cb (GtkMenuItem            *menuitem,
 			EmpathyContactList *list;
 
 			list = empathy_contact_list_store_get_list_iface (priv->store);
-			empathy_contact_list_remove (list, contact, 
+			empathy_contact_list_remove (list, contact,
 				_("Sorry, I don't want you in my contact list anymore."));
 		}
 
